@@ -6,7 +6,7 @@ use warnings;
 use autodie::Scope::Guard;
 
 # ABSTRACT: Hook stack for managing scopes via %^H
-our $VERSION = '2.24'; # VERSION
+our $VERSION = '2.27'; # VERSION
 
 my $H_KEY_STEM = __PACKAGE__ . '/guard';
 my $COUNTER = 0;
@@ -44,7 +44,10 @@ sub push_hook {
         #  then hook 2.  hook 3 will then be destroyed, but do nothing
         #  since its "frame" was already popped and finally hook 1
         #  will be popped and take its own frame with it.
-        $self->_pop_hook while @{$self} > $size;
+        #
+        #  We need to check that $self still exists since things can get weird
+        #  during global destruction.
+        $self->_pop_hook while $self && @{$self} > $size;
     });
     push(@{$self}, [$hook, $h_key]);
     return;
